@@ -11,123 +11,139 @@ use Regexp::Parsertron;
 my(@test)	=
 (
 {
-	count		=> 1,
+	item		=> 1,
 	expected	=> '(?^:(?#Comment))',
 	re			=> qr/(?#Comment)/,
 },
 {
-	count		=> 2,
-	expected	=> '(?^:(?))',
-	re			=> qr/(?)/,
-},
-{
-	count		=> 3,
+	item		=> 2,
 	expected	=> '(?^:(?a))',
 	re			=> qr/(?a)/,
 },
 {
-	count		=> 4,
+	item		=> 3,
 	expected	=> '(?^:(?a-i))',
 	re			=> qr/(?a-i)/,
 },
 {
-	count		=> 5,
+	item		=> 4,
 	expected	=> '(?^:(?^a))',
 	re			=> qr/(?^a)/,
 },
 {
-	count		=> 6,
+	item		=> 5,
 	expected	=> '(?^:(?a:))',
 	re			=> qr/(?a:)/,
 },
 {
-	count		=> 7,
+	item		=> 6,
 	expected	=> '(?^:(?a:b))',
 	re			=> qr/(?a:b)/,
 },
 {
-	count		=> 8,
-	expected	=> '(?^:(?:))',
-	re			=> qr/(?:)/,
-},
-{
-	count		=> 9,
+	item		=> 7,
 	expected	=> '(?^:[yY][eE][sS])',
 	re			=> qr/[yY][eE][sS]/,
 },
 {
-	count		=> 10,
+	item		=> 8,
 	expected	=> '(?^:(A|B))',
 	re			=> qr/(A|B)/,
 },
 {
-	count		=> 11,
+	item		=> 9,
 	expected	=> '(?^i:Perl|JavaScript)',
 	re			=> qr/Perl|JavaScript/i,
 },
 {
-	count		=> 12,
+	item		=> 10,
 	expected	=> '(?^i:Perl|JavaScript|C++)',
 	re			=> qr/Perl|JavaScript/i,
 },
 {
-	count		=> 13,
+	item		=> 11,
 	expected	=> '(?^:/ab+bc/)',
 	re			=> '/ab+bc/',
 },
 {
-	count		=> 14,
+	item		=> 12,
 	expected	=> '(?^:a)',
 	re			=> qr/a/,
 },
 {
-	count		=> 15,
-	expected	=> '(?^:(?:(?<n>foo)|(?<n>bar))\k<n>)',
-	re			=> qr/(?:(?<n>foo)|(?<n>bar))\k<n>/,
+	item		=> 13,
+	expected	=> '(?^i:Perl|JavaScript|(?:Flub|BCPL))',
+	re			=> qr/Perl|JavaScript|(?:Flub|BCPL)/i,
+},
+{
+	item		=> 14,
+	expected	=> "(?^:(?:(?<n>foo)|(?'n'bar)))",
+	re			=> qr/(?:(?<n>foo)|(?'n'bar))/,
+},
+{
+	item		=> 15,
+	expected	=> "(?^:(?:(?'n2'foo)|(?<n2>bar)))",
+	re			=> qr/(?:(?'n2'foo)|(?<n2>bar))/,
+},
+{
+	item		=> 16,
+	expected	=> "(?^:(?:(?'n'foo)|(?'n'bar)))",
+	re			=> qr/(?:(?'n'foo)|(?'n'bar))/,
+},
+{
+	item		=> 17,
+	expected	=> "(?^:(?:(?'n2'foo)|(?'n2'bar)))",
+	re			=> qr/(?:(?'n2'foo)|(?'n2'bar))/,
+},
+{
+	item		=> 18,
+	expected	=> '(?^:(?:(?<n2>foo)|(?<n2>bar))\k<n2>)',
+	re			=> qr/(?:(?<n2>foo)|(?<n2>bar))\k<n2>/,
 },
 );
 
 my($limit)	= shift || 0;
 my($parser)	= Regexp::Parsertron -> new(verbose => 2);
 my(%stats)	= (success => 0, total => 0);
+my($count)	= 0;
 
 my($expected);
 my($got);
 my($result);
-my($success);
+my($outcome);
 
 for my $test (@test)
 {
 	# Use this trick to run the tests one-at-a-time. See scripts/test.sh.
 
-	next if ( ($limit > 0) && ($$test{count} != $limit) );
+	next if ( ($limit > 0) && ($$test{item} != $limit) );
 
 	$stats{total}++;
 
 	$result		= $parser -> parse(re => $$test{re});
-	$success	= 1;
+	$outcome	= 1; # Return 1 for fail.
 
-	if ($$test{count} == 12)
+	if ($$test{item} == 10)
 	{
-		$parser -> append(text => '|C++', uid => 6);
+		$parser -> append(text => '|C++', uid => 5);
 	}
 
 	if ($result == 0)
 	{
 		$got		= $parser -> as_string;
 		$expected	= $$test{expected};
-		$success	= 0 if ($got eq $expected);
+		$outcome	= 0 if ($got eq $expected); # Return 0 for success.
 
-		$stats{success}++ if ($success == 0);
+		$stats{success}++ if ($outcome == 0);
 
-		say "$$test{count}: got: $got. expected: $expected. outcome: $success (0 is success). ";
+		say "Case: $$test{item}. got: $got. expected: $expected. outcome: $outcome (0 is success). ";
 	}
 	else
 	{
-		say "Test $$test{count} failed to return 0 from parse(). ";
+		say "Case $$test{item} failed to return 0 from parse(). ";
 	}
 
-	say '-' x 50;
+	say '-' x 100;
 
 	# Reset for next test.
 
